[![Upload Python Package](https://github.com/jadaliha/funsql/actions/workflows/pypi-publish.yml/badge.svg?branch=main)](https://github.com/jadaliha/funsql/actions/workflows/pypi-publish.yml)
[![Python application](https://github.com/jadaliha/funsql/actions/workflows/python-app.yml/badge.svg)](https://github.com/jadaliha/funsql/actions/workflows/python-app.yml)
# funsql
sql is fun. 
